/**
 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
/// <reference types="node" />
import type { Config, Global } from '@jest/types';
import type { JestEnvironment } from '@jest/environment';
import { TestResult } from '@jest/test-result';
import type { TestFileEvent } from 'jest-runner';
declare type Process = NodeJS.Process;
export declare const initialize: ({ config, environment, getPrettier, getBabelTraverse, globalConfig, localRequire, parentProcess, testPath, sendMessageToJest, }: {
    config: Config.ProjectConfig;
    environment: JestEnvironment;
    getPrettier: () => null | any;
    getBabelTraverse: () => Function;
    globalConfig: Config.GlobalConfig;
    localRequire: (path: Config.Path) => any;
    testPath: Config.Path;
    parentProcess: Process;
    sendMessageToJest?: import("jest-runner/build/types").TestFileEvent<"test-file-start" | "test-file-success" | "test-file-failure" | "test-case-result"> | undefined;
}) => Promise<{
    globals: {
        afterAll: (fn: Global.TestFn, timeout?: number | undefined) => void;
        afterEach: (fn: Global.TestFn, timeout?: number | undefined) => void;
        beforeAll: (fn: Global.TestFn, timeout?: number | undefined) => void;
        beforeEach: (fn: Global.TestFn, timeout?: number | undefined) => void;
        describe: {
            (blockName: string, blockFn: Global.BlockFn): void;
            each: (table: Global.EachTable, ...taggedTemplateData: Global.TemplateData) => (title: string, test: Global.EachTestFn, timeout?: number | undefined) => void;
            only: {
                (blockName: string, blockFn: Global.BlockFn): void;
                each: (table: Global.EachTable, ...taggedTemplateData: Global.TemplateData) => (title: string, test: Global.EachTestFn, timeout?: number | undefined) => void;
            };
            skip: {
                (blockName: string, blockFn: Global.BlockFn): void;
                each: (table: Global.EachTable, ...taggedTemplateData: Global.TemplateData) => (title: string, test: Global.EachTestFn, timeout?: number | undefined) => void;
            };
        };
        it: Global.It;
        test: Global.It;
    };
    snapshotState: import("jest-snapshot/build/State").default;
}>;
export declare const runAndTransformResultsToJestFormat: ({ config, globalConfig, testPath, }: {
    config: Config.ProjectConfig;
    globalConfig: Config.GlobalConfig;
    testPath: string;
}) => Promise<TestResult>;
export {};
